==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/JobManagementUI/src/com/clustercontrol/jobmanagement/composite/RunScheduleDetailListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite;

import java.util.Date;

import org.eclipse.jface.viewers.TableTreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.TableTree;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.bean.CommonTableTreeItem;
import com.clustercontrol.composite.CommonTableTreeViewer;
import com.clustercontrol.jobmanagement.action.GetRunScheduleDetailList;
import com.clustercontrol.jobmanagement.action.GetRunScheduleDetailListTableDefine;
import com.clustercontrol.jobmanagement.bean.RunScheduleDetailListTableDefine;
import com.clustercontrol.jobmanagement.composite.action.VerticalBarSelectionListener;
import com.clustercontrol.util.Messages;

/**
 * ͽٰܺݥåȥ饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class RunScheduleDetailListComposite extends Composite {
	protected CommonTableTreeViewer m_viewer = null;
    
    protected Label m_labelId = null;
    protected Label m_labelCount = null;
    
    protected String m_scheduleId = null;
    protected Date m_base = null;

    /**
     * 󥹥ȥ饯
     * 
     * @param parent
     * @param style
     * @since 2.0.0
     */
    public RunScheduleDetailListComposite(Composite parent, int style) {
        super(parent, style);
        initialize();
    }

    /**
     * 
     * 
     * @since 2.0.0
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;
        
        //ID٥
        m_labelId = new Label(this, SWT.LEFT);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        m_labelId.setLayoutData(gridData);
        
        //ͽٰܺơ֥
        TableTree tree = new TableTree(this, SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.SINGLE | SWT.BORDER);

        Table table = tree.getTable();
        table.setHeaderVisible(true);
        table.setLinesVisible(true);
        table.getHorizontalBar().setVisible(true);
        table.getHorizontalBar().setEnabled(true);
        table.getVerticalBar().setVisible(true);
        table.getVerticalBar().setEnabled(true);
        
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        tree.setLayoutData(gridData);
        
        m_labelCount = new Label(this, SWT.RIGHT);
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        m_labelCount.setLayoutData(gridData);

        m_viewer = new CommonTableTreeViewer(tree);
        m_viewer.createTableColumn(GetRunScheduleDetailListTableDefine.get(),
        		RunScheduleDetailListTableDefine.SORT_COLUMN_INDEX,
        		RunScheduleDetailListTableDefine.SORT_ORDER);
        
        m_viewer.getTableTree().getTable().getVerticalBar().addSelectionListener(
        		new VerticalBarSelectionListener(this));
    }

    /**
     * 
     * 
     * @since 2.0.0
     */
    public void update(String scheduleId) {
    	
        //ͽٰܺ
        GetRunScheduleDetailList getList = new GetRunScheduleDetailList();
        CommonTableTreeItem item = null;
        if (scheduleId != null && scheduleId.length() > 0) {
            item = getList.get(scheduleId);
        }

        m_viewer.setInput(item);
        m_viewer.expandAll();

//        Object[] args = { new Integer(info.size()) };
//        m_labelCount.setText(Messages.getString("records", args));
        
        m_scheduleId = scheduleId;

        //塼IDɽ
        if (m_scheduleId != null) {
        	m_labelId.setText(Messages.getString("schedule.id") + " : " + m_scheduleId);
        } else {
        	m_labelId.setText(Messages.getString("schedule.id") + " : ");
        }
    }
    
    /**
     * ΥݥåȤѤơ֥ĥ꡼ӥ塼֤ޤ
     * 
     * @return ơ֥ĥ꡼ӥ塼
     */
    public TableTreeViewer getTableTreeViewer() {
        return m_viewer;
    }

    /**
     * ΥݥåȤѤơ֥֤ޤ
     * 
     * @return ơ֥
     */
    public Table getTable() {
        return m_viewer.getTableTree().getTable();
    }

    /**
     * ΥݥåȤѤơ֥ĥ꡼֤ޤ
     * 
     * @return ơ֥ĥ꡼
     */
    public TableTree getTableTree() {
        return m_viewer.getTableTree();
    }
    
	/**
	 * @return
	 */
	public String getScheduleId() {
		return m_scheduleId;
	}
	
	/**
	 * @param scheduleId
	 */
	public void setScheduleId(String scheduleId) {
		m_scheduleId = scheduleId;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/JobManagementUI/src/com/clustercontrol/jobmanagement/composite/RunScheduleDetailListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite;

import java.util.Date;

import org.eclipse.jface.viewers.TableTreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.TableTree;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.bean.CommonTableTreeItem;
import com.clustercontrol.composite.CommonTableTreeViewer;
import com.clustercontrol.jobmanagement.action.GetRunScheduleDetailList;
import com.clustercontrol.jobmanagement.action.GetRunScheduleDetailListTableDefine;
import com.clustercontrol.jobmanagement.bean.RunScheduleDetailListTableDefine;
import com.clustercontrol.jobmanagement.composite.action.VerticalBarSelectionListener;
import com.clustercontrol.util.Messages;

/**
 * 予定詳細一覧コンポジットクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class RunScheduleDetailListComposite extends Composite {
	protected CommonTableTreeViewer m_viewer = null;
    
    protected Label m_labelId = null;
    protected Label m_labelCount = null;
    
    protected String m_scheduleId = null;
    protected Date m_base = null;

    /**
     * コンストラクタ
     * 
     * @param parent
     * @param style
     * @since 2.0.0
     */
    public RunScheduleDetailListComposite(Composite parent, int style) {
        super(parent, style);
        initialize();
    }

    /**
     * 初期化処理
     * 
     * @since 2.0.0
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;
        
        //ジョブIDラベル作成
        m_labelId = new Label(this, SWT.LEFT);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        m_labelId.setLayoutData(gridData);
        
        //予定詳細一覧テーブル作成
        TableTree tree = new TableTree(this, SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.SINGLE | SWT.BORDER);

        Table table = tree.getTable();
        table.setHeaderVisible(true);
        table.setLinesVisible(true);
        table.getHorizontalBar().setVisible(true);
        table.getHorizontalBar().setEnabled(true);
        table.getVerticalBar().setVisible(true);
        table.getVerticalBar().setEnabled(true);
        
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        tree.setLayoutData(gridData);
        
        m_labelCount = new Label(this, SWT.RIGHT);
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        m_labelCount.setLayoutData(gridData);

        m_viewer = new CommonTableTreeViewer(tree);
        m_viewer.createTableColumn(GetRunScheduleDetailListTableDefine.get(),
        		RunScheduleDetailListTableDefine.SORT_COLUMN_INDEX,
        		RunScheduleDetailListTableDefine.SORT_ORDER);
        
        m_viewer.getTableTree().getTable().getVerticalBar().addSelectionListener(
        		new VerticalBarSelectionListener(this));
    }

    /**
     * 更新処理
     * 
     * @since 2.0.0
     */
    public void update(String scheduleId) {
    	
        //予定詳細一覧情報取得
        GetRunScheduleDetailList getList = new GetRunScheduleDetailList();
        CommonTableTreeItem item = null;
        if (scheduleId != null && scheduleId.length() > 0) {
            item = getList.get(scheduleId);
        }

        m_viewer.setInput(item);
        m_viewer.expandAll();

//        Object[] args = { new Integer(info.size()) };
//        m_labelCount.setText(Messages.getString("records", args));
        
        m_scheduleId = scheduleId;

        //スケジュールIDを表示
        if (m_scheduleId != null) {
        	m_labelId.setText(Messages.getString("schedule.id") + " : " + m_scheduleId);
        } else {
        	m_labelId.setText(Messages.getString("schedule.id") + " : ");
        }
    }
    
    /**
     * このコンポジットが利用するテーブルツリービューアを返します。
     * 
     * @return テーブルツリービューア
     */
    public TableTreeViewer getTableTreeViewer() {
        return m_viewer;
    }

    /**
     * このコンポジットが利用するテーブルを返します。
     * 
     * @return テーブル
     */
    public Table getTable() {
        return m_viewer.getTableTree().getTable();
    }

    /**
     * このコンポジットが利用するテーブルツリーを返します。
     * 
     * @return テーブルツリー
     */
    public TableTree getTableTree() {
        return m_viewer.getTableTree();
    }
    
	/**
	 * @return
	 */
	public String getScheduleId() {
		return m_scheduleId;
	}
	
	/**
	 * @param scheduleId
	 */
	public void setScheduleId(String scheduleId) {
		m_scheduleId = scheduleId;
	}
}
